@@ -20,10 +20,10 @@ df <- 2
 storage.mode(t) <- "double"
 storage.mode(df) <- "double"
 stopifnot(isequal(1 - pchisq(t, df = df), ### P-values!!!
-          .Call("R_quadformConditionalPvalue", t, df)))
+          .Call("R_quadformConditionalPvalue", t, df, PACKAGE = "party")))
 
 stopifnot(isequal(2*pnorm(-t), 
-          .Call("R_maxabsConditionalPvalue", t, matrix(1), as.integer(1), 0.0, 0.0, 0.0)))
+          .Call("R_maxabsConditionalPvalue", t, matrix(1), as.integer(1), 0.0, 0.0, 0.0, PACKAGE = "party")))
 
 
 maxpts <- 25000
@@ -35,19 +35,19 @@ tol <- 1e-10
 a <- 1.96
 b <- diag(2)
 
-p1 <- .Call("R_maxabsConditionalPvalue", a, b, maxpts, abseps, releps, tol)
+p1 <- .Call("R_maxabsConditionalPvalue", a, b, maxpts, abseps, releps, tol, PACKAGE = "party")
 p2 <- pmvnorm(lower = rep(-a,2), upper = rep(a,2), corr = b)
 stopifnot(isequal(round(p1, 3), round(1 - p2, 3)))
 
 b <- diag(4)
-p1 <- .Call("R_maxabsConditionalPvalue", a, b, maxpts, abseps, releps, tol)
+p1 <- .Call("R_maxabsConditionalPvalue", a, b, maxpts, abseps, releps, tol, PACKAGE = "party")
 p2 <- pmvnorm(lower = rep(-a,4), upper = rep(a,4), corr = b)
 stopifnot(isequal(round(p1, 3), round(1 - p2, 3)))
 
 b <- diag(4)
 b[upper.tri(b)] <- c(0.1, 0.2, 0.3)
 b[lower.tri(b)] <- t(b)[lower.tri(b)]
-p1 <- .Call("R_maxabsConditionalPvalue", a, b, maxpts, abseps, releps, tol)
+p1 <- .Call("R_maxabsConditionalPvalue", a, b, maxpts, abseps, releps, tol, PACKAGE = "party")
 p2 <- pmvnorm(lower = rep(-a,4), upper = rep(a,4), corr = b)
 stopifnot(isequal(round(p1, 3), round(1 - p2, 3)))
 
@@ -68,7 +68,7 @@ gtctrl <- new("GlobalTestControl")
 gtctrl@testtype <- factor("MonteCarlo", levels = levels(gtctrl@testtype))
 gtctrl@nresample <- as.integer(19999)
 
-pvals <- .Call("R_GlobalTest", ls, ls@weights, tm, varctrl, gtctrl)
+pvals <- .Call("R_GlobalTest", ls, ls@weights, tm, varctrl, gtctrl, PACKAGE = "party")
 wstat <- abs(qnorm(wilcox.test(x1 ~ y, data = mydata, 
              exact = FALSE, correct = FALSE)$p.value/2))
 wpval <- wilcox.test(x1 ~ y, data = mydata, exact = TRUE)$p.value
@@ -93,7 +93,7 @@ gtctrl <- new("GlobalTestControl")
 gtctrl@testtype <- factor("Univariate", levels = levels(gtctrl@testtype))
 gtctrl@nresample <- as.integer(19999)
 
-pvals <- .Call("R_GlobalTest", ls, ls@weights, tm, varctrl, gtctrl)
+pvals <- .Call("R_GlobalTest", ls, ls@weights, tm, varctrl, gtctrl, PACKAGE = "party")
 wstat <- c(abs(qnorm(wilcox.test(x1 ~ y, data = mydata, 
                exact = FALSE, correct = FALSE)$p.value/2)),
            abs(qnorm(wilcox.test(x2 ~ y, data = mydata, 
@@ -112,6 +112,6 @@ stopifnot(isequal(wpval, 1 - pvals[[2]]))
 ### Monte-Carlo approximations of P-Values, min-P approach
 gtctrl@testtype <- factor("MonteCarlo", levels = levels(gtctrl@testtype))
 gtctrl@nresample <- as.integer(19999)
-pvals <- .Call("R_GlobalTest", ls, ls@weights, tm, varctrl, gtctrl)
+pvals <- .Call("R_GlobalTest", ls, ls@weights, tm, varctrl, gtctrl, PACKAGE = "party")
 stopifnot(isequal(wstat, pvals[[1]]))
 stopifnot(all(wpval < (1 - pvals[[2]])))
